@@ -82,9 +82,11 @@ def do_files(*files):
     '''Optimize all given files'''
     touched_files = set(pth for kv in store.originals.items() for pth in kv)
     for pth in [path(p).abspath() for p in files]:
-        if not pth in touched_files:
+        if pth in touched_files:
+            logging.info('ignoring %s', pth)
+        else:
             handle_file(pth)
-
+            
 def list_files():
     '''list all files in internal store'''
     logging.info('optimized files:')
